@@ -5,6 +5,7 @@ import subprocess
 import json
 import os
 import asyncio
+import re
 from dotenv import load_dotenv
 import helix
 from fastmcp import FastMCP
@@ -25,8 +26,6 @@ async def find_git_root(start_path: str = None) -> str:
     Returns:
         Path to the git repository root, or None if not in a git repository
     """
-    # First, try to get workspace root from common environment variables
-    # MCP clients like Cursor might set these
     env_vars = [
         "MCP_WORKSPACE_ROOT",
         "CURSOR_WORKSPACE_ROOT", 
@@ -38,15 +37,12 @@ async def find_git_root(start_path: str = None) -> str:
     for env_var in env_vars:
         workspace_from_env = os.getenv(env_var)
         if workspace_from_env and os.path.isdir(workspace_from_env):
-            # Try to find git root starting from this directory
             start_path = workspace_from_env
             break
     
     if start_path is None:
         start_path = os.getcwd()
     
-    # Use git rev-parse --show-toplevel to find the git root
-    # Use asyncio.create_subprocess_exec directly to avoid circular dependency
     try:
         process = await asyncio.create_subprocess_exec(
             "git",
@@ -64,40 +60,25 @@ async def find_git_root(start_path: str = None) -> str:
             if git_root:
                 return git_root
     except (FileNotFoundError, OSError):
-        # Git not found or other OS error
         pass
     
     return None
 
 
-# Helper function to run subprocess calls asynchronously to avoid blocking stdio
 async def run_subprocess(args: List[str], **kwargs) -> subprocess.CompletedProcess:
     """Run subprocess calls asynchronously to avoid blocking stdio transport."""
-    # Use asyncio.create_subprocess_exec instead of subprocess.run to avoid blocking
     capture_output = kwargs.pop('capture_output', False)
     text = kwargs.pop('text', False)
-    check = kwargs.pop('check', False)  # Handle check parameter separately
+    check = kwargs.pop('check', False)
     
-    # CRITICAL: Set stdin to DEVNULL to prevent subprocess from inheriting 
-    # the MCP stdio stdin, which causes deadlocks
     stdin = kwargs.pop('stdin', asyncio.subprocess.DEVNULL)
-    
-    # CRITICAL: Always capture stdout/stderr to PIPE to prevent subprocess output
-    # from leaking into the MCP stdio communication channel (which breaks JSON parsing)
-    # In stdio mode, parent's stdout/stderr IS the MCP communication channel, so we must
-    # always capture subprocess output to prevent git messages from breaking JSON protocol
     stdout = asyncio.subprocess.PIPE
     stderr = asyncio.subprocess.PIPE
-    # Remove any stdout/stderr from kwargs since we're overriding them
     kwargs.pop('stdout', None)
     kwargs.pop('stderr', None)
-    
-    # Only pass valid parameters to asyncio.create_subprocess_exec
-    # Filter out any subprocess.run() specific parameters that aren't valid
-    # Explicitly remove check and other invalid params to prevent errors
-    kwargs.pop('check', None)  # Extra safety: ensure check is removed
-    kwargs.pop('timeout', None)  # timeout handled by asyncio.wait_for elsewhere
-    kwargs.pop('input', None)  # input not supported in async subprocess
+    kwargs.pop('check', None)
+    kwargs.pop('timeout', None)
+    kwargs.pop('input', None)
     
     valid_exec_kwargs = {}
     allowed_params = {'cwd', 'env', 'start_new_session', 'shell', 'preexec_fn', 
@@ -106,10 +87,6 @@ async def run_subprocess(args: List[str], **kwargs) -> subprocess.CompletedProce
     for key, value in kwargs.items():
         if key in allowed_params:
             valid_exec_kwargs[key] = value
-        # Silently ignore other parameters
-    
-    # Final safety check: ensure check is not in valid_exec_kwargs
-    assert 'check' not in valid_exec_kwargs, "check parameter should not be passed to subprocess"
     
     process = await asyncio.create_subprocess_exec(
         *args,
@@ -121,7 +98,6 @@ async def run_subprocess(args: List[str], **kwargs) -> subprocess.CompletedProce
     
     stdout_data, stderr_data = await process.communicate()
     
-    # Create a CompletedProcess-like object
     result = subprocess.CompletedProcess(
         args=args,
         returncode=process.returncode,
@@ -129,7 +105,6 @@ async def run_subprocess(args: List[str], **kwargs) -> subprocess.CompletedProce
         stderr=stderr_data.decode('utf-8') if text and stderr_data else stderr_data,
     )
     
-    # If check=True, raise CalledProcessError on non-zero return code
     if check and result.returncode != 0:
         raise subprocess.CalledProcessError(
             result.returncode, args, result.stdout, result.stderr
@@ -137,19 +112,6 @@ async def run_subprocess(args: List[str], **kwargs) -> subprocess.CompletedProce
     
     return result
 
-@mcp.tool
-async def draft_pr():
-    instructions = [
-        "step 1: grep for CONTRIBUTING.md or similar documentation in the repository. If unable to find it, look for any contributing guidelines in the repository.",
-        "step 2: if not found, follow best practices for writing a pull request.",
-        "step 3: use the edit file tool to write a new PR_DRAFT.md file for the project.",
-    ]
-    result = "draft pr instructions: \n\n"
-    for i, instruction in enumerate(instructions, 1):
-        result += f"{i}. {instruction}\n\n"
-    return result
-
-
 @mcp.tool(
     name="split_commit",
     description="Splits a large unified diff / commit into smaller semantically-grouped commits.",
@@ -163,18 +125,13 @@ async def split_commit(workspace_root: str = None):
                         If not provided, will attempt to detect from environment variables or current directory.
     """
     try:
-        # Detect the git repository root
         if workspace_root:
-            # If provided, use it directly
             detected_root = await find_git_root(workspace_root)
             if detected_root:
                 workspace_root = detected_root
             elif not os.path.isdir(workspace_root):
                 return f"error: provided workspace_root '{workspace_root}' does not exist or is not a directory."
-            # If workspace_root is provided but not a git repo, we'll still try to use it
-            # (git commands will fail with a clear error if it's not a git repo)
         else:
-            # Try to auto-detect
             workspace_root = await find_git_root()
             if not workspace_root:
                 cwd = os.getcwd()
@@ -186,8 +143,6 @@ async def split_commit(workspace_root: str = None):
                     f"  2. Provide the workspace_root parameter with the path to your git repository root."
                 )
         
-        # 1) Collect changed files and per-file unified diffs
-        # Check staged, unstaged, and untracked files
         staged_proc = await run_subprocess(
             ["git", "diff", "--cached", "--name-only"], 
             capture_output=True, 
@@ -207,9 +162,6 @@ async def split_commit(workspace_root: str = None):
             cwd=workspace_root
         )
         
-        # Check if git commands failed (might indicate not a git repo)
-        # Note: git commands can return non-zero even in valid repos (e.g., no changes)
-        # Only error if we get explicit "not a git repository" messages
         error_messages = []
         if staged_proc.returncode != 0 and staged_proc.stderr:
             error_messages.append(staged_proc.stderr)
@@ -238,7 +190,6 @@ async def split_commit(workspace_root: str = None):
 
         file_to_diff: Dict[str, str] = {}
         for path in changed_files:
-            # Try staged diff first, then unstaged
             p = await run_subprocess(
                 ["git", "diff", "--cached", "--", path], 
                 capture_output=True, 
@@ -257,69 +208,54 @@ async def split_commit(workspace_root: str = None):
                 if p.returncode == 0 and p.stdout.strip():
                     file_to_diff[path] = p.stdout
                 else:
-                    # For untracked/new files, read the entire file content as the "diff"
-                    # Paths from git are relative to workspace root, so join them
                     file_path = os.path.join(workspace_root, path) if not os.path.isabs(path) else path
                     try:
                         with open(file_path, "r", encoding="utf-8") as f:
                             content = f.read()
-                            # Format as a new file addition diff
                             file_to_diff[path] = (
                                 f"diff --git a/{path} b/{path}\nnew file mode 100644\n--- /dev/null\n+++ b/{path}\n@@ -0,0 +1,{len(content.splitlines())} @@\n+{chr(10).join('+'+line for line in content.splitlines())}"
                             )
                     except (FileNotFoundError, UnicodeDecodeError):
-                        # File might not exist or not be text
                         continue
 
         if not file_to_diff:
             return "no per-file diffs produced"
 
-        # 2) Embed each file's diff with Voyage (preconfigured in voyage_service)
-        suggestions: List[Tuple[str, str]] = []  # (file_path, suggested_message)
+        suggestions: List[Tuple[str, str]] = []
 
-        # Connect Helix client - supports both local and cloud via environment variables
         use_local = os.getenv("HELIX_LOCAL", "false").lower() == "true"
         
         if use_local:
             db = helix.Client(local=True)
         else:
-            # Use cloud deployment from helix.toml (production.fly)
-            # Helix SDK automatically reads helix.toml and uses the configured deployment
             api_endpoint = os.getenv("HELIX_API_ENDPOINT", "")
-            if not HELIX_API_ENDPOINT:
-                return "error: HELIX API ENDPOINT is not set"
+            if not api_endpoint:
+                return "error: HELIX_API_ENDPOINT is not set"
             db = helix.Client(local=False, api_endpoint=api_endpoint)
 
         for file_path, diff_text in file_to_diff.items():
-            # 2a) Embed with timeout (5 seconds)
             try:
                 vec_batch = await asyncio.wait_for(
                     asyncio.to_thread(embed_code, diff_text, file_path=file_path),
                     timeout=5
                 )
             except asyncio.TimeoutError:
-                return f"error: embedding timed out for {file_path} (expected to always work)"
+                return f"error: embedding timed out for {file_path}"
             except Exception as embed_exc:
-                return f"error: embedding failed for {file_path}: {str(embed_exc)} (expected to always work)"
+                return f"error: embedding failed for {file_path}: {str(embed_exc)}"
             
             if not vec_batch:
                 return f"error: embedding returned empty result for {file_path}"
             vec = vec_batch[0]
 
             try:
-                # 3) ANN search for similar diffs; k kept small to keep it snappy
-                # Add timeout to database query (5 seconds)
                 res = await asyncio.wait_for(
                     asyncio.to_thread(db.query, "getSimilarDiffsByVector", {"vec": vec, "k": 8}),
                     timeout=5
                 )
-            except asyncio.TimeoutError:
-                # If database query times out, continue without examples
+            except (asyncio.TimeoutError, Exception):
                 res = []
-            except Exception as db_exc:
-                # If database query fails, continue without examples
-                res = []
-            # Result rows include commit_message, summary, file_path
+            
             examples = []
             if isinstance(res, list):
                 for row in res[:5]:
@@ -334,12 +270,18 @@ async def split_commit(workspace_root: str = None):
 
             example_block = "\n\n".join(examples) if examples else ""
             
-            # Helper function to detect and reject generic messages
             def is_generic_message(msg: str) -> bool:
                 """Check if a commit message is too generic."""
                 if not msg:
                     return True
                 msg_lower = msg.lower().strip()
+                
+                # Reject reasoning tag patterns
+                if ("redacted_reasoning" in msg_lower or 
+                    "<think>" in msg_lower or 
+                    "</think>" in msg_lower):
+                    return True
+                
                 generic_patterns = [
                     "update ",
                     "fix bug",
@@ -352,11 +294,9 @@ async def split_commit(workspace_root: str = None):
                     "minor",
                     "temporary",
                 ]
-                # Check if message starts with generic patterns
                 for pattern in generic_patterns:
                     if msg_lower.startswith(pattern):
                         return True
-                # Check if message is just a filename (e.g., "Update app.py")
                 if msg_lower.startswith("update ") and len(msg_lower.split()) <= 3:
                     return True
                 return False
@@ -397,47 +337,55 @@ EXAMPLES OF GOOD MESSAGES:
 - "docs(readme): add installation instructions"
 
 EXAMPLES OF BAD MESSAGES (DO NOT USE):
-- "Update app.py" ❌
-- "Fix bug" ❌
-- "Refactor code" ❌
-- "Changes" ❌
+- "Update app.py"
+- "Fix bug"
+- "Refactor code"
+- "Changes"
 
 Remember: Your output must be SPECIFIC and describe WHAT changed, not generic file operations."""
             )
             user_prompt = (
-                "Generate a commit message for this diff. Consider similar past changes if given.\n\n"
+                "/no_think\n\nGenerate a commit message for this diff. Consider similar past changes if given.\n\n"
                 f"DIFF (truncated if long):\n{diff_text}\n\n"
                 f"SIMILAR EXAMPLES:\n{example_block}\n\n"
                 "Output ONLY the commit message title, nothing else."
             )
             
-            # Call Cerebras inference - should always work
             try:
                 raw_response = await asyncio.wait_for(
-                    complete(user_prompt, system=system_prompt, max_tokens=100),
+                    complete(user_prompt, system=system_prompt, temperature=0.0),
                     timeout=30.0
                 )
             except asyncio.TimeoutError:
-                return f"error: Cerebras inference timed out for {file_path} (expected to always work)"
+                return f"error: Cerebras inference timed out for {file_path}"
             except Exception as llm_exc:
-                return f"error: Cerebras inference failed for {file_path}: {str(llm_exc)} (expected to always work)"
+                return f"error: Cerebras inference failed for {file_path}: {str(llm_exc)}"
             
             if not raw_response:
                 return f"error: Cerebras inference returned empty response for {file_path}"
             
-            commit_message = raw_response.strip().splitlines()[0].strip()
+            # Strip reasoning tags from response (e.g., <think>, </think>, <think>, etc.)
+            cleaned_response = raw_response.strip()
+            # Remove XML-like reasoning tags
+            cleaned_response = re.sub(r'<[^>]*think[^>]*>', '', cleaned_response, flags=re.IGNORECASE)
+            cleaned_response = re.sub(r'<[^>]*reasoning[^>]*>', '', cleaned_response, flags=re.IGNORECASE)
+            cleaned_response = re.sub(r'<[^>]*redacted[^>]*>', '', cleaned_response, flags=re.IGNORECASE)
+            
+            # Extract first non-empty line after cleaning
+            lines = [line.strip() for line in cleaned_response.splitlines() if line.strip()]
+            if not lines:
+                return f"error: No valid commit message found in response for {file_path} after cleaning reasoning tags"
+            
+            commit_message = lines[0]
             
-            # Remove quotes if present
             if commit_message.startswith('"') and commit_message.endswith('"'):
                 commit_message = commit_message[1:-1]
             if commit_message.startswith("'") and commit_message.endswith("'"):
                 commit_message = commit_message[1:-1]
             
-            # Validate the message is not generic - fail if it is
             if not commit_message or is_generic_message(commit_message):
                 return (
-                    f"error: Cerebras inference generated generic message '{commit_message}' for {file_path}. "
-                    f"Please improve the system prompt or check the inference output."
+                    f"error: Cerebras inference generated generic message '{commit_message}' for {file_path}"
                 )
 
             suggestions.append((file_path, commit_message))
@@ -445,7 +393,6 @@ Remember: Your output must be SPECIFIC and describe WHAT changed, not generic fi
         if not suggestions:
             return "no commit suggestions could be generated"
 
-        # 4) Commit each file separately with its suggested message
         for file_path, message in suggestions:
             try:
                 await run_subprocess(
@@ -465,16 +412,11 @@ Remember: Your output must be SPECIFIC and describe WHAT changed, not generic fi
                     "Ensure the file exists, is not conflicted, and git is functioning properly."
                 )
 
-        # 5) Return a compact report of what was committed
         report = {"commits": [{"file": f, "message": m} for f, m in suggestions]}
         return json.dumps(report, indent=2)
 
     except Exception as e:
-        return (
-            f"failed to split commit: {str(e)}\n"
-            f"Exception type: {type(e).__name__}\n"
-            "Ensure git is available and HelixDB is reachable on localhost:6969."
-        )
+        return f"failed to split commit: {str(e)}"
 
 
 @mcp.tool
